# Security Policy

## Supported Versions

Versions of pyerge are currently being supported with security updates.

| Version | Supported          |
|---------|--------------------|
| 0.5.x   | :white_check_mark: |
| <0.4.x  | :x:                |

## Reporting a Vulnerability

Use internal issues.
